@@ -2,7 +2,7 @@ package Dist::Zilla::Plugin::Test::CPAN::Changes;
 use strict;
 use warnings;
 # ABSTRACT: release tests for your changelog
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use Moose;
 use Data::Section -setup;
@@ -14,7 +14,6 @@ with
 has changelog => (
     is      => 'ro',
     isa     => 'Str',
-    predicate => 'has_changelog',
     default => 'Changes',
 );
 
@@ -24,7 +23,7 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        $self->has_changelog ? ( changelog => $self->Changes ) : (),
+        changelog => $self->changelog,
         blessed($self) ne __PACKAGE__
             ? ( version => (defined __PACKAGE__->VERSION ? __PACKAGE__->VERSION : 'dev') )
             : (),
@@ -88,7 +87,7 @@ Dist::Zilla::Plugin::Test::CPAN::Changes - release tests for your changelog
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =for test_synopsis BEGIN { die "SKIP: synopsis isn't perl code" }
 
